@@ -47,6 +47,8 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'cloudfront.ListPublicKeys.PublicKeyList',
     'cloudfront.ListStreamingDistributions.StreamingDistributionList',
     'cloudfront.ListKeyValueStores.KeyValueStoreList',
+    'cloudfront.ListDistributionsByConnectionFunction.DistributionList',
+    'cloudfront.ListDistributionsByTrustStore.DistributionList',
     'codedeploy.ListDeploymentGroups.applicationName',
     'dms.DescribeTableStatistics.ReplicationTaskArn',
     'dms.DescribeReplicationTaskAssessmentResults.BucketName',
@@ -117,9 +119,6 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     's3.ListParts.UploadId',
     's3.ListParts.AbortRuleId',
     's3.ListParts.RequestCharged',
-    'sms.GetReplicationRuns.replicationJob',
-    'sms.GetServers.lastModifiedOn',
-    'sms.GetServers.serverCatalogStatus',
     'storagegateway.DescribeTapeRecoveryPoints.GatewayARN',
     'storagegateway.DescribeVTLDevices.GatewayARN',
     'storagegateway.ListVolumes.GatewayARN',
