@@ -70,14 +70,23 @@ class BaseS3TransferCommandTest(BaseAWSCommandParamsTest):
         )
 
     def head_object_response(self, **override_kwargs):
-        response = {'ContentLength': 100, 'LastModified': '00:00:00Z'}
+        response = {
+            'ContentLength': 100,
+            'LastModified': '00:00:00Z',
+            'ETag': '"foo-1"',
+        }
         response.update(override_kwargs)
         return response
 
     def list_objects_response(self, keys, **override_kwargs):
         contents = []
         for key in keys:
-            content = {'Key': key, 'LastModified': '00:00:00Z', 'Size': 100}
+            content = {
+                'Key': key,
+                'LastModified': '00:00:00Z',
+                'Size': 100,
+                'ETag': '"foo-1"',
+            }
             if override_kwargs:
                 content.update(override_kwargs)
             contents.append(content)
@@ -296,6 +305,7 @@ class BaseS3CLIRunnerTest(unittest.TestCase):
                 headers={
                     'Content-Length': str(size),
                     'Last-Modified': 'Thu, 11 Feb 2021 04:24:23 GMT',
+                    'ETag': 'foobar',
                 }
             )
         )
@@ -313,6 +323,7 @@ class BaseS3CLIRunnerTest(unittest.TestCase):
                 '<LastModified>2015-12-08T18:26:43.000Z</LastModified>'
                 f'<Key>{key}</Key>'
                 f'<Size>{size}</Size>'
+                f'<ETag>foobar</ETag>'
                 '</Contents>'
             )
         xml_body += '</ListBucketResult>'
