@@ -77,6 +77,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                         "Key": key,
                         "Size": 3,
                         "LastModified": "2014-01-09T20:45:49.000Z",
+                        "ETag": '"c8afdb36c52cf4727836669019e69222-"',
                     }
                 ],
             },
@@ -125,6 +126,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                         'LastModified': '00:00:00Z',
                         'StorageClass': 'GLACIER',
                         'Size': 100,
+                        'ETag': '"foo-1"',
                     },
                 ],
                 'CommonPrefixes': [],
@@ -421,6 +423,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                     upload_id,
                     CopySourceRange=mock.ANY,
                     PartNumber=1,
+                    CopySourceIfMatch='"foo-1"',
                 ),
                 self.complete_mpu_request('bucket', 'key', upload_id, 1),
                 self.put_object_tagging_request(
@@ -449,6 +452,7 @@ class TestSyncCommand(BaseS3TransferCommandTest):
                         'LastModified': '00:00:00Z',
                         'Size': 100,
                         'ChecksumAlgorithm': 'SHA1',
+                        'ETag': 'myetag',
                     }
                 ],
                 'CommonPrefixes': [],
