@@ -13,7 +13,7 @@
 import awscrt.s3
 import pytest
 import s3transfer.crt
-from awscrt.s3 import S3RequestTlsMode
+from awscrt.s3 import S3FileIoOptions, S3RequestTlsMode
 from botocore.config import Config
 from botocore.credentials import Credentials
 from botocore.httpsession import DEFAULT_CA_BUNDLE
@@ -59,6 +59,7 @@ def transfer_manager_factory():
     session = mock.Mock(Session)
     session.get_config_variable.return_value = None
     session.get_default_client_config.return_value = None
+    session.get_scoped_config.return_value = {}
     return TransferManagerFactory(session)
 
 
@@ -158,6 +159,7 @@ class TestTransferManagerFactory(unittest.TestCase):
         self.session = mock.Mock(Session)
         self.session.get_config_variable.return_value = None
         self.session.get_default_client_config.return_value = None
+        self.session.get_scoped_config.return_value = {}
         self.factory = TransferManagerFactory(self.session)
         self.params = {
             'region': 'us-west-2',
@@ -483,6 +485,27 @@ class TestTransferManagerFactory(unittest.TestCase):
         self.assert_is_crt_manager(transfer_manager)
         self.assert_expected_throughput_target_gbps(mock_crt_client, 8)
 
+    @mock.patch('s3transfer.crt.S3Client')
+    def test_fio_options_configure_for_crt_manager(self, mock_crt_client):
+        self.runtime_config = self.get_runtime_config(
+            preferred_transfer_client='crt',
+            should_stream=True,
+            disk_throughput=1000**3,
+            direct_io=True,
+        )
+        transfer_manager = self.factory.create_transfer_manager(
+            self.params, self.runtime_config
+        )
+        expected_fio_options = S3FileIoOptions(
+            should_stream=True,
+            disk_throughput_gbps=8.0,
+            direct_io=True,
+        )
+        self.assert_is_crt_manager(transfer_manager)
+        self.assertEqual(
+            mock_crt_client.call_args[1]['fio_options'], expected_fio_options
+        )
+
     @mock.patch('s3transfer.crt.get_recommended_throughput_target_gbps')
     @mock.patch('s3transfer.crt.S3Client')
     def test_target_bandwidth_uses_crt_recommended_throughput(
@@ -520,6 +543,11 @@ class TestTransferManagerFactory(unittest.TestCase):
         self, mock_crt_client
     ):
         part_size = 16 * (1024**2)
+        self.session.get_scoped_config.return_value = {
+            's3': {
+                'multipart_chunksize': part_size,
+            }
+        }
         self.runtime_config = self.get_runtime_config(
             preferred_transfer_client='crt', multipart_chunksize=part_size
         )
@@ -529,6 +557,23 @@ class TestTransferManagerFactory(unittest.TestCase):
         self.assert_is_crt_manager(transfer_manager)
         self.assertEqual(mock_crt_client.call_args[1]['part_size'], part_size)
 
+    @mock.patch('s3transfer.crt.S3Client')
+    def test_default_part_size_for_crt_manager(self, mock_crt_client):
+        part_size = 16 * (1024**2)
+        # Explicitly showing that the user has not configured
+        # `multipart_chunksize`.
+        self.session.get_scoped_config.return_value = {'s3': {}}
+        self.runtime_config = self.get_runtime_config(
+            preferred_transfer_client='crt', multipart_chunksize=part_size
+        )
+        transfer_manager = self.factory.create_transfer_manager(
+            self.params, self.runtime_config
+        )
+        self.assert_is_crt_manager(transfer_manager)
+        # When `multipart_chunksize` isn't explicitly provided, configure
+        # `part_size` to `None`.
+        self.assertEqual(mock_crt_client.call_args[1]['part_size'], None)
+
 
 @pytest.mark.parametrize(
     'preferred_transfer_client,extra_params,'
